package com.ynet.life.file.parser;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import java.io.BufferedWriter;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonDownloadTXTFileParser.class */
public class CommonDownloadTXTFileParser implements CommonDownloadFileParserInterface {
    @Override // com.ynet.life.file.parser.CommonDownloadFileParserInterface
    public byte[] writeToFile(List titles, List recordList, List outputFields, List outputFormats, List lastList, String filePathName, String encoding) throws TranFailException {
        StringBuffer fileContent = new StringBuffer();
        Map lengthMap = new HashMap();
        if (titles != null) {
            for (int i = 0; i < titles.size(); i++) {
                lengthMap.put(Integer.valueOf(i), Integer.valueOf(((String) titles.get(i)).getBytes().length));
            }
        }
        if (recordList != null) {
            Iterator ite = recordList.iterator();
            while (ite.hasNext()) {
                Map record = (Map) ite.next();
                for (int i2 = 0; i2 < outputFields.size(); i2++) {
                    Object obj = record.get(outputFields.get(i2)) == null ? "" : record.get(outputFields.get(i2));
                    String format = (String) outputFormats.get(i2);
                    String fieldValue = DownloadFileParserUtil.transformFormat(obj.toString(), format);
                    int length = 0;
                    if (fieldValue != null) {
                        length = fieldValue.getBytes().length;
                    }
                    if (lengthMap.containsKey(Integer.valueOf(i2))) {
                        if (((Integer) lengthMap.get(Integer.valueOf(i2))).compareTo(Integer.valueOf(length)) < 0) {
                            lengthMap.put(Integer.valueOf(i2), Integer.valueOf(length));
                        }
                    } else {
                        lengthMap.put(Integer.valueOf(i2), Integer.valueOf(length));
                    }
                }
            }
        }
        if (titles != null) {
            for (int i3 = 0; i3 < titles.size(); i3++) {
                String titleValue = (String) titles.get(i3);
                if (lengthMap.containsKey(Integer.valueOf(i3))) {
                    titleValue = appendSpace(titleValue, ((Integer) lengthMap.get(Integer.valueOf(i3))).intValue());
                }
                fileContent.append(titleValue).append("\t");
            }
            StringBuffer stringBuffer = new StringBuffer(fileContent.substring(0, fileContent.length() - 1));
            fileContent = stringBuffer;
            stringBuffer.append(LifeFile.LINE_SEPARATOR);
        }
        if (recordList != null) {
            Iterator iterator = recordList.iterator();
            while (iterator.hasNext()) {
                Map record2 = (Map) iterator.next();
                for (int i4 = 0; i4 < outputFields.size(); i4++) {
                    Object obj2 = record2.get(outputFields.get(i4)) == null ? "" : record2.get(outputFields.get(i4));
                    String format2 = (String) outputFormats.get(i4);
                    String fieldValue2 = DownloadFileParserUtil.transformFormat(obj2.toString(), format2);
                    if (lengthMap.containsKey(Integer.valueOf(i4))) {
                        fieldValue2 = appendSpace(fieldValue2, ((Integer) lengthMap.get(Integer.valueOf(i4))).intValue());
                    }
                    fileContent.append(fieldValue2).append("\t");
                }
                fileContent.append(LifeFile.LINE_SEPARATOR);
            }
        }
        if (lastList.size() > 0) {
            fileContent.append(LifeFile.LINE_SEPARATOR);
            for (int i5 = 0; i5 < lastList.size(); i5++) {
                Map filedMap = (Map) lastList.get(i5);
                for (Object key : filedMap.keySet()) {
                    String value = (String) filedMap.get(key);
                    fileContent.append(key + ":" + value + "\t");
                }
            }
        }
        StringBuffer sb = new StringBuffer();
        String tempString = fileContent.toString();
        for (int i6 = 0; i6 < tempString.length(); i6++) {
            char ch = tempString.charAt(i6);
            if (ch == '\n') {
                sb.append("\r\n");
            } else if (ch != '\r') {
                if (ch == ' ') {
                    sb.append(" ");
                } else {
                    sb.append(ch);
                }
            }
        }
        byte[] b = writeStringToFile(filePathName, sb.toString(), encoding, false);
        if (b.length > 0) {
            return b;
        }
        return null;
    }

    private String appendSpace(String src, int length) {
        String result = src;
        if (src == null) {
            result = "";
        }
        int appendLen = length - result.getBytes().length;
        for (int i = 0; i < appendLen; i++) {
            result = String.valueOf(result) + " ";
        }
        return result;
    }

    public static byte[] writeStringToFile(String filePathName, String fileContent, String encoding, boolean append) throws TranFailException {
        BufferedWriter fileWriter = null;
        FileOutputStream outFile = null;
        OutputStreamWriter outWriter = null;
        try {
            try {
                outFile = new FileOutputStream(filePathName, append);
                outWriter = new OutputStreamWriter(outFile, encoding);
                BufferedWriter bufferedWriter = new BufferedWriter(outWriter);
                fileWriter = bufferedWriter;
                bufferedWriter.write(fileContent);
                byte[] bytes = fileWriter.toString().getBytes();
                try {
                    fileWriter.close();
                    outWriter.close();
                    outFile.close();
                } catch (IOException ex) {
                    Trace.logWarning("LifeFile", "下载文件时中文出错", ex);
                }
                return bytes;
            } catch (IOException ex2) {
                Trace.logError("LifeFile", "文件写入失败", ex2);
                throw new TranFailException("EBLN0000", "文件写入失败", ex2);
            }
        } catch (Throwable th) {
            if (fileWriter != null) {
                try {
                    fileWriter.close();
                } catch (IOException ex3) {
                    Trace.logWarning("LifeFile", "下载文件时中文出错", ex3);
                    throw th;
                }
            }
            if (outWriter != null) {
                outWriter.close();
            }
            if (outFile != null) {
                outFile.close();
            }
            throw th;
        }
    }
}
